@@ -180,7 +180,7 @@ def flog(
             return result
 
         if asyncio.iscoroutinefunction(funk) or asyncio.iscoroutine(funk):
-            return _flog_decorator_async
+            return _flog_decorator_async  # type: ignore
         return _flog_decorator
 
     return _flog(funk) if funk else _flog  # type: ignore
@@ -191,6 +191,11 @@ def handlers() -> Dict[int, Handler]:
     return logger._core.handlers  # type: ignore
 
 
+def reset() -> None:
+    logger.remove()
+    logger.add(_sys.stderr)
+
+
 __hoisted__ = [
     '_change_activation',
     '_core',
@@ -252,7 +257,6 @@ success = LAGER.success
 trace = LAGER.trace
 warning = LAGER.warning
 
-
 __all__ = [
     'loglevel',
     'flog',
